# Diamond C

A module to test diamond dependencies

## Install
```bash
$ python3 -m pip install diamond-c
```

## Usage 
```python3
from diamond import c

c.c()
```

OR

```python3
from diamond.c import c

c()
```
